Summary:	Library for configuring and customizing font access
Name:		fontconfig
Version:	2.14.2
Release:	18%{?dist}
License:	MIT and Public Domain and UCD
URL:		https://www.freedesktop.org/wiki/Software/fontconfig/
Source0:        https://www.freedesktop.org/software/fontconfig/release/%{name}-%{version}.tar.xz
Patch0001: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/c22908828fb2dbfdf38733d119adc1cf5fe00173.patch
Patch0002: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/42b12fc7c0855cddecdf6f4a0a26b897d53432a5.patch
Patch0003: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/b269e6853be6278cc9fe06b1c1d92f7d31504c01.patch
Patch0004: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/eaa335e7c4686c622f31e691f8a41fdf30ea42b3.patch
Patch0005: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/ab765827101787d49c0a66b23addc1f68f99a455.patch
Patch0006: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/3a0ed05722feec5c478d076d87a64bf15f4bacdb.patch
Patch0007: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/aae5ff1f2e1be978272c41bf809d15b6e47b1e2c.patch
Patch0008: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/ec20037908963870e27572fadef766cc8a6d9818.patch
Patch0009: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/b892c2196d0d9e74df61620e79ad8e846b01637d.patch
Patch0010: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/9164a7bcbd3be022f074bb0530dd5c12e3c83b44.patch
Patch0011: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/ad58277b71415b714009bee33f04e8c18c7ab44d.patch
Patch0012: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/71a6a990aa8578ddd7140fe0b2c9f87508d2b59b.patch
Patch0013: https://gitlab.freedesktop.org/fontconfig/fontconfig/-/commit/084752e737a12c99800b2a35ea80eab11a12eabe.patch

Patch3000:	fontconfig-disable-network-required-test.patch

BuildRequires:	make autoconf automake libtool gettext
BuildRequires:	libxml2-devel fontpackages-devel
BuildRequires:	freetype-devel >= 2.9.1
BuildRequires:	gperf

Requires:	fonts-filesystem freetype font(:lang=en)
Requires(pre):	freetype >= 2.9.1
Requires(pre):  xml-common
Requires(post):	grep coreutils
Requires(postun): xml-common
# dejavu-fonts providing font(dejavusans) can also provide font(:lang=en)
Suggests:	font(dejavusans)

%description
Fontconfig is a library for configuring and customizing font access. It
contains two essential modules: the configuration module, which builds
an internal configuration from XML files, and the matching module,
which accepts font patterns and returns the nearest matching font.

%package	devel
Summary:	Header files and development docs for fontconfig
Requires:	%{name} = %{version}-%{release}
Requires:	freetype-devel >= 2.9.1
Requires:	pkgconfig gettext

%description	devel
Header files and developer docs for developing programs using fontconfig package.


%prep
%autosetup -p1

%build
# Don't rebuild the docs, but nstall the included ones.
export HASDOCBOOK=no
autoreconf
%configure	--enable-libxml2 --disable-static --docdir=%{_docdir}/%{name} \
                --with-cache-dir=/usr/lib/fontconfig/cache \
                --with-add-fonts=/usr/share/X11/fonts/Type1,/usr/share/X11/fonts/TTF,/usr/local/share/fonts
%make_build


%install
%make_install
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} \;

#The file has no symlink, but other conf files have symlink, so create symlink for it
ln -s %{_fontconfig_templatedir}/25-unhint-nonlatin.conf $RPM_BUILD_ROOT%{_sysconfdir}/fonts/conf.d/

%find_lang %{name}
%find_lang %{name}-conf


%check
make check

%post
# Force regeneration of all fontconfig cache files
mkdir -p /usr/lib/fontconfig/cache
[[ -d %{_localstatedir}/cache/fontconfig ]] && rm -rf %{_localstatedir}/cache/fontconfig/* 2> /dev/null || :
HOME=/root %{_bindir}/fc-cache -f

%transfiletriggerin -- /usr/share/fonts /usr/share/X11/fonts/Type1 /usr/share/X11/fonts/TTF /usr/local/share/fonts
HOME=/root %{_bindir}/fc-cache -s

%transfiletriggerpostun -- /usr/share/fonts /usr/share/X11/fonts/Type1 /usr/share/X11/fonts/TTF /usr/local/share/fonts
HOME=/root %{_bindir}/fc-cache -s

%posttrans
if [ -e %{_sysconfdir}/xml/catalog ]; then
  %{_bindir}/xmlcatalog --noout --add system \
                        "urn:fontconfig:fonts.dtd" \
                        "file://%{_datadir}/xml/fontconfig/fonts.dtd" \
                        %{_sysconfdir}/xml/catalog
fi

%postun
if [ $1 == 0 ] && [ -e %{_sysconfdir}/xml/catalog ]; then
  %{_bindir}/xmlcatalog --noout --del "urn:fontconfig:fonts.dtd" %{_sysconfdir}/xml/catalog
fi

%files -f %{name}.lang -f %{name}-conf.lang
%license COPYING
%doc README AUTHORS ChangeLog
%doc %{_sysconfdir}/fonts/conf.d/README
%{_libdir}/libfontconfig.so.*
%{_bindir}/*

%config %{_sysconfdir}/fonts/fonts.conf
%config(noreplace) %{_sysconfdir}/fonts/conf.d/*.conf

%dir %{_datadir}/%{name}/conf.avail
%{_datadir}/%{name}/conf.avail/*.conf

%{_datadir}/xml/fontconfig
%dir /usr/lib/fontconfig/cache
%{_mandir}/man1/*
%{_mandir}/man5/*

%{_docdir}/%{name}/fontconfig-user.html
%{_docdir}/%{name}/fontconfig-user.pdf
%{_docdir}/%{name}/fontconfig-user.txt

%files devel
%{_libdir}/libfontconfig.so
%{_libdir}/pkgconfig/*
%{_includedir}/fontconfig
%{_mandir}/man3/*
%{_datadir}/gettext/its/fontconfig.its
%{_datadir}/gettext/its/fontconfig.loc
%{_docdir}/%{name}/%{name}-devel/
%{_docdir}/%{name}/fontconfig-devel.pdf
%{_docdir}/%{name}/fontconfig-devel.txt

%changelog
* Thu Jan 02 2025 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-18
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] 084752e737a12c99800b2a35ea80eab11a12eabe.patch: Accept integer for pixelsize

* Thu Jan 02 2025 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-17
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] 71a6a990aa8578ddd7140fe0b2c9f87508d2b59b.patch: Fix a memory leak in fc-list/fc-query/fc-scan

* Tue Dec 31 2024 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-16
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] ad58277b71415b714009bee33f04e8c18c7ab44d.patch: Fix FcSerialize null pointer usage
- [Bug Fix] 9164a7bcbd3be022f074bb0530dd5c12e3c83b44.patch: Fix qsort nullpointer issue

* Tue Dec 31 2024 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-15
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] b892c2196d0d9e74df61620e79ad8e846b01637d.patch: Ensure config is locked during retry in FcConfigReference

* Tue Dec 31 2024 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-14
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] ec20037908963870e27572fadef766cc8a6d9818.patch: Unlock on allocation failure in FcCacheInsert

* Mon Dec 30 2024 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-13
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] aae5ff1f2e1be978272c41bf809d15b6e47b1e2c.patch: Remove redundant leaf assignment in fcfreetype.c

* Mon Dec 30 2024 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-12
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] 3a0ed05722feec5c478d076d87a64bf15f4bacdb.patch: Use proper postscriptname for named instance if any

* Mon Dec 30 2024 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-11
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] ab765827101787d49c0a66b23addc1f68f99a455.patch: Set FcTypeVoid if no valid types to convert

* Fri Dec 27 2024 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-10
- Apply patches from rpm-tracker
- [Bug Fix] eaa335e7c4686c622f31e691f8a41fdf30ea42b3.patch: Fix a memory leak in _get_real_paths_from_prefix

* Fri Dec 27 2024 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-9
- Apply patches from rpm-tracker
- [Bug Fix] b269e6853be6278cc9fe06b1c1d92f7d31504c01.patch: Fix invalid escape character \s

* Wed Dec 25 2024 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-8
- Apply patches from rpm-tracker
- [Bug Fix] 42b12fc7c0855cddecdf6f4a0a26b897d53432a5.patch: More information when no writable cache directories

* Tue Dec 24 2024 Tracker Robot <trackbot@opencloudos.tech> - 2.14.2-7
- Apply patches from rpm-tracker
- [Bug Fix] c22908828fb2dbfdf38733d119adc1cf5fe00173.patch: Clean up .uuid files with fc-cache -f too

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.14.2-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.14.2-5
- Rebuilt for loongarch release

* Mon Oct 09 2023 Wang Guodong <gordonwwang@tencent.com> - 2.14.2-4
- Move fonts(:lang=) into Requires

* Wed Sep 13 2023 rockerzhu <rockerzhu@tencent.com> - 2.14.2-3
- Delete patches to provide fonts(:lang=)

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.14.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Jul 28 2023 Shuo Wang <abushwang@tencent.com> - 2.14.2-1
- update to 2.14.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.14.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.14.0-2
- Rebuilt for OpenCloudOS Stream 23

* Tue May 24 2022 rockerzhu <rockerzhu@tencent.com> - 2.14.0-1
- Initial build
